@@ -112,13 +112,29 @@ public:
         VTagSize _semiSharp       : 1;  // variable
         VTagSize _semiSharpEdges  : 1;  // variable
         VTagSize _rule            : 4;  // variable when _semiSharp
-        VTagSize _incomplete      : 1;  // variable for sparse refinement
+
+        //  These next to tags are complementary -- the "incomplete" tag is only
+        //  relevant for refined levels while the "incident an irregular face" tag
+        //  is only relevant for the base level.  They could be combined as both
+        //  indicate "no full regular ring" around a vertex
+        VTagSize _incomplete      : 1;  // variable only set in refined levels
+        VTagSize _incidIrregFace  : 1;  // variable only set in base level
 
         //  Tags indicating incident infinitely-sharp (permanent) features
         VTagSize _infSharpEdges   : 1;  // fixed
         VTagSize _infSharpCrease  : 1;  // fixed
         VTagSize _infIrregular    : 1;  // fixed
 
+        //  Alternate constructor and accessor for dealing with integer bits directly:
+        explicit VTag(VTagSize bits) {
+            std::memcpy(this, &bits, sizeof(bits));
+        }
+        VTagSize getBits() const {
+            VTagSize bits;
+            std::memcpy(&bits, this, sizeof(bits));
+            return bits;
+        }
+
         static VTag BitwiseOr(VTag const vTags[], int size = 4);
     };
     struct ETag {
@@ -134,6 +150,16 @@ public:
         ETagSize _infSharp     : 1;  // fixed
         ETagSize _semiSharp    : 1;  // variable
 
+        //  Alternate constructor and accessor for dealing with integer bits directly:
+        explicit ETag(ETagSize bits) {
+            std::memcpy(this, &bits, sizeof(bits));
+        }
+        ETagSize getBits() const {
+            ETagSize bits;
+            std::memcpy(&bits, this, sizeof(bits));
+            return bits;
+        }
+
         static ETag BitwiseOr(ETag const eTags[], int size = 4);
     };
     struct FTag {
@@ -172,6 +198,7 @@ public:
 
         LocalIndex _numFaces;
         LocalIndex _startFace;
+        LocalIndex _cornerInSpan;
 
         unsigned short _periodic : 1;
         unsigned short _sharp    : 1;
